@@ -670,7 +670,7 @@ bool FileRead::saveFile( const KURL &url, bool copyimages, bool saveCompressed )
         if( saveFile(_tmpfile->name(), copyimages, saveCompressed) ) {
             // upload the file
              TDEIO::Job * job = TDEIO::file_copy( KURL::fromPathOrURL( _tmpfile->name() ), _currentURL, -1, true /*overwrite*/ );
-             connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ), this, TQT_SLOT( slotUploadFinished (TDEIO::Job *) ) );
+             connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( slotUploadFinished (TDEIO::Job *) ) );
             return true;
         }
     }
@@ -689,7 +689,7 @@ bool FileRead::saveFile( const TQString &filename, bool copyimages, bool saveCom
     TQFile file(filename);
     TQStringList copyJOB;
 
-    stream.setDevice(TQT_TQIODEVICE(&buffer));
+    stream.setDevice(&buffer);
 
     if ( (!file.open(IO_WriteOnly)) || (!buffer.open(IO_WriteOnly)) )
     {
@@ -847,7 +847,7 @@ bool FileRead::saveResults( const KURL &url, const TQString &results )
         if( saveResults(_tmpfile->name(), results) ) {
             // upload the file
              TDEIO::Job * job = TDEIO::file_copy( KURL::fromPathOrURL( _tmpfile->name() ), _currentURL, -1, true /*overwrite*/ );
-             connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ), this, TQT_SLOT( slotUploadFinished (TDEIO::Job *) ) );
+             connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( slotUploadFinished (TDEIO::Job *) ) );
             return true;
         }
     }
@@ -862,7 +862,7 @@ bool FileRead::saveResults( const TQString &filename, const TQString &results )
     TQFile file(filename);
     TQStringList copyJOB;
 
-    stream.setDevice(TQT_TQIODEVICE(&file));
+    stream.setDevice(&file);
 
     if(!file.open(IO_WriteOnly))
     {
