@@ -74,30 +74,30 @@ KHangMan::~KHangMan()
 void KHangMan::setupActions()
 {
     // Game->New
-    TDEAction *action = new TDEAction(i18n("&New"), "document-new", CTRL+Key_N , TQT_TQOBJECT(m_view), TQT_SLOT(slotNewGame()), actionCollection(), "file_new");
+    TDEAction *action = new TDEAction(i18n("&New"), "document-new", CTRL+Key_N , m_view, TQ_SLOT(slotNewGame()), actionCollection(), "file_new");
     action->setToolTip(i18n( "Play with a new word" ));
 
     // Game->Get Words in New Language
-    new TDEAction( i18n("&Get Words in New Language..."), "knewstuff", CTRL+Key_G, TQT_TQOBJECT(this), TQT_SLOT( slotDownloadNewStuff() ), actionCollection(), "downloadnewstuff" );
+    new TDEAction( i18n("&Get Words in New Language..."), "knewstuff", CTRL+Key_G, this, TQ_SLOT( slotDownloadNewStuff() ), actionCollection(), "downloadnewstuff" );
 
-    KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(slotQuit()), actionCollection());
+    KStdAction::quit(this, TQ_SLOT(slotQuit()), actionCollection());
     
     m_levelAction = new TDESelectAction(i18n("Le&vel"), 0,  actionCollection(), "combo_level");
     m_levelAction->setToolTip(i18n( "Choose the level" ));
     m_levelAction->setWhatsThis(i18n( "Choose the level of difficulty" ));
-	connect(m_levelAction, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeLevel(int)));
+	connect(m_levelAction, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotChangeLevel(int)));
 
     // Action for selecting language.
     m_languageAction = new TDESelectAction(i18n("&Language"), 0, actionCollection(), "languages");
     m_languageAction->setItems(m_languageNames);
     m_languageAction->setCurrentItem(m_languages.findIndex(Prefs::selectedLanguage()));
-    connect(m_languageAction, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeLanguage(int)));
+    connect(m_languageAction, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotChangeLanguage(int)));
     
-    KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(optionsPreferences()), actionCollection());
+    KStdAction::preferences(this, TQ_SLOT(optionsPreferences()), actionCollection());
 
     // Mode. Currently hard coded into Sea and Desert themes.
     TQStringList modes;
-    m_modeAction = new TDESelectAction(i18n("L&ook"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotChangeMode()),  actionCollection(), "combo_mode");
+    m_modeAction = new TDESelectAction(i18n("L&ook"), 0, this, TQ_SLOT(slotChangeMode()),  actionCollection(), "combo_mode");
     modes += i18n("&Sea Theme");
     modes += i18n("&Desert Theme");
     m_modeAction->setItems(modes);
@@ -228,7 +228,7 @@ void KHangMan::setLanguages()
     for (uint i=0;  i<m_languages.count(); i++) {
         TQString tmp = m_languages[i];
         if (!config->readEntry(tmp))
-            config->writeEntry(tmp, TQString(TQDate::currentDate().toString(Qt::ISODate)));
+            config->writeEntry(tmp, TQString(TQDate::currentDate().toString(TQt::ISODate)));
     }
 
     // We look in $TDEDIR/share/locale/all_languages from
@@ -382,7 +382,7 @@ void KHangMan::optionsPreferences()
     Timer *m_timer = new Timer();
     dialog->addPage(m_timer, i18n("Timers"), "clock");
 
-    connect(dialog, TQT_SIGNAL(settingsChanged()), TQT_TQOBJECT(this), TQT_SLOT(updateSettings()));
+    connect(dialog, TQ_SIGNAL(settingsChanged()), this, TQ_SLOT(updateSettings()));
 
     dialog->show();
 }
@@ -457,8 +457,8 @@ void KHangMan::loadLangToolBar()
 
 	for (int i=0; i<(int) m_allData.count(); i++)
 	    secondToolbar->insertButton (charIcon(m_allData[i].at(0)), i, 
-					 TQT_SIGNAL( clicked() ), TQT_TQOBJECT(this), 
-					 TQT_SLOT( slotPasteChar()), true,  
+					 TQ_SIGNAL( clicked() ), this, 
+					 TQ_SLOT( slotPasteChar()), true,  
 					 i18n("Inserts the character %1").arg(m_allData[i]), i+1 );
     }
 
