@@ -536,7 +536,7 @@ KigDocument* KigFilterNative::load07( const TQString& file, const TQDomElement&
         if ( ! ok ) width = -1;
 
         tmp = e.attribute( "style" );
-        Qt::PenStyle style = ObjectDrawer::styleFromString( tmp );
+        TQt::PenStyle style = ObjectDrawer::styleFromString( tmp );
 
         tmp = e.attribute( "point-style" );
         int pointstyle = ObjectDrawer::pointStyleFromString( tmp );
