@@ -105,7 +105,7 @@ void KLatinVerbs::loadDatabase()
 	
 	TQString fileName = "klatin/data/verbs/" + databaseFile;
 
-	if (TQFile::exists(locate("data", fileName)) == FALSE) {
+	if (!TQFile::exists(locate("data", fileName))) {
 		KMessageBox::error(this, i18n("Could not load verb-definition file, check KLatin installation."), i18n("Error with KLatin"));
 		goBack();
 	}
