@@ -24,7 +24,7 @@ class imagesequence : public imgSequenceDlg
   
 
 public:
-  imagesequence(TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+  imagesequence(TQWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );
   ~imagesequence();
   
 
