@@ -14,11 +14,11 @@
 
 class INDIFITSConf : public INDIConf
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
-  INDIFITSConf(TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+  INDIFITSConf(TQWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );
   ~INDIFITSConf();
   /*$PUBLIC_FUNCTIONS$*/
 
