@@ -57,9 +57,9 @@ class INDI_P : public TQObject
     TQLabel      *label_w;		/* Label widget */
     TQPushButton *set_w;		        /* set button */
     
-    TQSpacerItem    *HorSpacer;		/*Qt::Horizontal spacer */
-    TQHBoxLayout    *PHBox;   		/*Qt::Horizontal container */
-    TQVBoxLayout    *PVBox;   		/*Qt::Vertical container */
+    TQSpacerItem    *HorSpacer;		/* Horizontal spacer */
+    TQHBoxLayout    *PHBox;   		/* Horizontal container */
+    TQVBoxLayout    *PVBox;   		/* Vertical container */
     
     TQButtonGroup   *groupB;		/* group button for radio and check boxes (Elements) */
     KComboBox      *om_w;		/* Combo box for menu */
