@@ -106,7 +106,7 @@ void KStars::setLocalTime(int yr, int mth, int day, int hr, int min, int sec) {
 
 void KStars::waitFor( double t ) {
 	kapp->dcopClient()->suspend();
-	TQTimer::singleShot( int( 1000.*t ), this, TQT_SLOT( resumeDCOP() ) );
+	TQTimer::singleShot( int( 1000.*t ), this, TQ_SLOT( resumeDCOP() ) );
 }
 
 void KStars::waitForKey( const TQString k ) {
@@ -420,7 +420,7 @@ void KStars::exportImage( const TQString url, int w, int h ) {
 		else if ( ext.lower() == "bmp" ) { format = "BMP"; }
 		else { kdWarning() << i18n( "Could not parse image format of %1; assuming PNG." ).arg( fname ) << endl; }
 
-		map()->exportSkyImage( TQT_TQPAINTDEVICE(&skyimage) );
+		map()->exportSkyImage( &skyimage );
 		kapp->processEvents(10000);
 
 		//skyImage is the size of the sky map.  The requested image size is w x h.
@@ -775,10 +775,10 @@ void KStars::waitForINDIAction(TQString deviceName, TQString action)
     el = dev->findElem(action);
     if (!el) return;
 
-    TQObject::connect(el->pp, TQT_SIGNAL(okState()), this, TQT_SLOT(resumeDCOP(void )));
+    TQObject::connect(el->pp, TQ_SIGNAL(okState()), this, TQ_SLOT(resumeDCOP(void )));
   }
   else
-    TQObject::connect(prop, TQT_SIGNAL(okState()), this, TQT_SLOT(resumeDCOP(void )));
+    TQObject::connect(prop, TQ_SIGNAL(okState()), this, TQ_SLOT(resumeDCOP(void )));
 
   kapp->dcopClient()->suspend();
 
@@ -977,7 +977,7 @@ void KStars::setINDIFilterNum(TQString deviceName, int filter_num)
   prop = dev->findProp("FILTER_SLOT");
   if (!prop) return;
 
-  el   = prop->findElement("SLOT");
+  el   = prop->findElement("TQ_SLOT");
   if (!el) return;
 
   if (el->write_w)
