@@ -67,40 +67,40 @@ ObservingList::ObservingList( KStars *_ks, TQWidget* parent )
 	ui->MiniButton->hide();
 
 	//Connections
-	connect( this, TQT_SIGNAL( closeClicked() ), this, TQT_SLOT( slotClose() ) );
-	connect( ui->TableStack, TQT_SIGNAL( aboutToShow( TQWidget* ) ),
-			this, TQT_SLOT( slotPrepTable( TQWidget* ) ) );
-	connect( ui->FullTable, TQT_SIGNAL( selectionChanged() ),
-			this, TQT_SLOT( slotNewSelection() ) );
-	connect( ui->TinyTable, TQT_SIGNAL( selectionChanged() ),
-			this, TQT_SLOT( slotNewSelection() ) );
-	connect( ui->FullTable, TQT_SIGNAL( doubleClicked( TQListViewItem*, const TQPoint&, int) ),
-			this, TQT_SLOT( slotCenterObject() ) );
-	connect( ui->TinyTable, TQT_SIGNAL( doubleClicked( TQListBoxItem* ) ),
-			this, TQT_SLOT( slotCenterObject() ) );
-	connect( ui->RemoveButton, TQT_SIGNAL( clicked() ),
-			this, TQT_SLOT( slotRemoveObjects() ) );
-	connect( ui->CenterButton, TQT_SIGNAL( clicked() ),
-			this, TQT_SLOT( slotCenterObject() ) );
-	connect( ui->ScopeButton, TQT_SIGNAL( clicked() ),
-			this, TQT_SLOT( slotSlewToObject() ) );
-	connect( ui->DetailsButton, TQT_SIGNAL( clicked() ),
-			this, TQT_SLOT( slotDetails() ) );
-	connect( ui->AVTButton, TQT_SIGNAL( clicked() ),
-			this, TQT_SLOT( slotAVT() ) );
+	connect( this, TQ_SIGNAL( closeClicked() ), this, TQ_SLOT( slotClose() ) );
+	connect( ui->TableStack, TQ_SIGNAL( aboutToShow( TQWidget* ) ),
+			this, TQ_SLOT( slotPrepTable( TQWidget* ) ) );
+	connect( ui->FullTable, TQ_SIGNAL( selectionChanged() ),
+			this, TQ_SLOT( slotNewSelection() ) );
+	connect( ui->TinyTable, TQ_SIGNAL( selectionChanged() ),
+			this, TQ_SLOT( slotNewSelection() ) );
+	connect( ui->FullTable, TQ_SIGNAL( doubleClicked( TQListViewItem*, const TQPoint&, int) ),
+			this, TQ_SLOT( slotCenterObject() ) );
+	connect( ui->TinyTable, TQ_SIGNAL( doubleClicked( TQListBoxItem* ) ),
+			this, TQ_SLOT( slotCenterObject() ) );
+	connect( ui->RemoveButton, TQ_SIGNAL( clicked() ),
+			this, TQ_SLOT( slotRemoveObjects() ) );
+	connect( ui->CenterButton, TQ_SIGNAL( clicked() ),
+			this, TQ_SLOT( slotCenterObject() ) );
+	connect( ui->ScopeButton, TQ_SIGNAL( clicked() ),
+			this, TQ_SLOT( slotSlewToObject() ) );
+	connect( ui->DetailsButton, TQ_SIGNAL( clicked() ),
+			this, TQ_SLOT( slotDetails() ) );
+	connect( ui->AVTButton, TQ_SIGNAL( clicked() ),
+			this, TQ_SLOT( slotAVT() ) );
 
-	connect( ui->OpenButton, TQT_SIGNAL( clicked() ),
-			this, TQT_SLOT( slotOpenList() ) );
-	connect( ui->SaveButton, TQT_SIGNAL( clicked() ),
-			this, TQT_SLOT( slotSaveList() ) );
-	connect( ui->SaveAsButton, TQT_SIGNAL( clicked() ),
-			this, TQT_SLOT( slotSaveListAs() ) );
-	connect( ui->WizardButton, TQT_SIGNAL( clicked() ),
-			this, TQT_SLOT( slotWizard() ) );
+	connect( ui->OpenButton, TQ_SIGNAL( clicked() ),
+			this, TQ_SLOT( slotOpenList() ) );
+	connect( ui->SaveButton, TQ_SIGNAL( clicked() ),
+			this, TQ_SLOT( slotSaveList() ) );
+	connect( ui->SaveAsButton, TQ_SIGNAL( clicked() ),
+			this, TQ_SLOT( slotSaveListAs() ) );
+	connect( ui->WizardButton, TQ_SIGNAL( clicked() ),
+			this, TQ_SLOT( slotWizard() ) );
 
 	//FIXME: enable MiniButton
-// 	connect( ui->MiniButton, TQT_SIGNAL( clicked() ),
-// 			this, TQT_SLOT( slotToggleSize() ) );
+// 	connect( ui->MiniButton, TQ_SIGNAL( clicked() ),
+// 			this, TQ_SLOT( slotToggleSize() ) );
 
 	obsList.setAutoDelete( false ); //do NOT delete removed pointers!
 
