@@ -30,7 +30,7 @@
 
 class ViewOptions : public ViewOptionsBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
