@@ -250,7 +250,7 @@ class MultipleChoice;
   * This class contains the expressions of your vocabulary
   ************************************************************/
 
-class KDE_EXPORT kvoctrainDoc : public TQObject
+class TDE_EXPORT kvoctrainDoc : public TQObject
 {
   TQ_OBJECT
   
