@@ -323,7 +323,7 @@ void RandomQueryDlg::setQuery(TQString org,
        timercount = mqtime;
        mw->timebar->setTotalSteps(timercount);
        mw->timebar->setProgress(timercount);
-       qtimer->start(1000, TRUE);
+       qtimer->start(1000, true);
      }
      else
        mw->timebar->setEnabled(false);
@@ -522,7 +522,7 @@ void RandomQueryDlg::timeoutReached()
    if (timercount > 0) {
      timercount--;
      mw->timebar->setProgress(timercount);
-     qtimer->start(1000, TRUE);
+     qtimer->start(1000, true);
    }
 
    if (timercount <= 0) {
