@@ -26,7 +26,7 @@
 */
 class DlgSort : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 
