@@ -49,7 +49,7 @@ class ExtDateTable;
  *
  * @short A date selection widget.
  **/
-class KDE_EXPORT ExtDatePicker: public TQFrame
+class TDE_EXPORT ExtDatePicker: public TQFrame
 {
   TQ_OBJECT
   
@@ -106,7 +106,7 @@ public:
    * Returns the selected date.
    * @deprecated
    **/
-  const ExtDate& getDate() const KDE_DEPRECATED;
+  const ExtDate& getDate() const TDE_DEPRECATED;
 
   /**
    * @returns the selected date.
